==============================================================
 ``nti.externalization.interfaces``: Interfaces and constants
==============================================================


.. automodule:: nti.externalization.interfaces
..
  For some reason, even though these are in __all__, they don't get
  documented unless we list them explicitly.

.. autoclass:: nti.externalization._base_interfaces.StandardExternalFields
   :member-order: bysource
.. autoclass:: nti.externalization._base_interfaces.StandardInternalFields
.. autodata:: nti.externalization._base_interfaces.DEFAULT_EXTERNALIZATION_POLICY
